# === class: pulsevtm::log_export_routing_software
#
# This class is a direct implementation of brocadvtm::log_export
#
# Please refer to the documentation in that module for more information
#
class pulsevtm::log_export_routing_software (
  $ensure                = present,
  $basic__appliance_only = true,
  $basic__enabled        = false,
  $basic__files          = '["%ZEUSHOME%/zxtm/log/routing_sw*"]',
  $basic__history        = 'none',
  $basic__history_period = 10,
  $basic__metadata       = '[{"name":"source","value":"rhilog"},{"name":"sourcetype","value":"zxtm_rhi_log"}]',
  $basic__note           = 'Log files generated by the traffic manager\'s OSPF and BGP routing software.',
){
  include pulsevtm
  $ip              = $pulsevtm::rest_ip
  $port            = $pulsevtm::rest_port
  $user            = $pulsevtm::rest_user
  $pass            = $pulsevtm::rest_pass
  $purge           = $pulsevtm::purge
  $purge_state_dir = $pulsevtm::purge_state_dir

  info ("Configuring log_export_routing_software ${name}")
  vtmrest { 'log_export/Routing%20Software':
    ensure   => $ensure,
    before   => Class[pulsevtm::purge],
    endpoint => "https://${ip}:${port}/api/tm/6.0/config/active",
    username => $user,
    password => $pass,
    content  => template('pulsevtm/log_export.erb'),
    type     => 'application/json',
    internal => 'log_export_routing_software',
    failfast => $pulsevtm::failfast,
    debug    => $pulsevtm::debug,
  }

  if ( $purge ) {
    ensure_resource('file', "${purge_state_dir}/log_export", {ensure => present})
    file_line { 'log_export/Routing%20Software':
      line => 'log_export/Routing%20Software',
      path => "${purge_state_dir}/log_export",
    }
  }
}
